@@ -1,4 +1,5 @@
 {-# LANGUAGE Safe #-}
+
 {- arch-tag: HVIO main file
 Copyright (c) 2004-2011 John Goerzen <jgoerzen@complete.org>
 
@@ -10,9 +11,8 @@ For license and copyright information, see the file LICENSE
 {- |
    Module     : System.IO.HVIO
    Copyright  : Copyright (C) 2004-2011 John Goerzen
-   License    : BSD3
+   SPDX-License-Identifier: BSD-3-Clause
 
-   Maintainer : John Goerzen <jgoerzen@complete.org>
    Stability  : provisional
    Portability: portable
 
@@ -120,14 +120,14 @@ module System.IO.HVIO(-- * Implementation Classes
                     )
 where
 
-import System.IO
-import System.IO.Error
-import qualified Control.Exception (catch, IOException)
-import Control.Concurrent.MVar
-import Data.IORef
-import Foreign.Ptr
-import Foreign.C
-import Foreign.Storable
+import           Control.Concurrent.MVar
+import qualified Control.Exception       (IOException, catch)
+import           Data.IORef
+import           Foreign.C
+import           Foreign.Ptr
+import           Foreign.Storable
+import           System.IO
+import           System.IO.Error
 
 {- | This is the generic I\/O support class.  All objects that are to be used
 in the HVIO system must provide an instance of 'HVIO'.
@@ -286,7 +286,7 @@ class (Show a) => HVIO a where
                 let func = do c <- vGetChar h
                               case c of
                                      '\n' -> return accum
-                                     x -> accum `seq` loop (accum ++ [x])
+                                     x    -> accum `seq` loop (accum ++ [x])
                     handler e = if isEOFError e then return accum
                                 else ioError e
                     in Control.Exception.catch func handler
@@ -294,7 +294,7 @@ class (Show a) => HVIO a where
             do firstchar <- vGetChar h
                case firstchar of
                    '\n' -> return []
-                   x -> loop [x]
+                   x    -> loop [x]
 
     vGetContents h =
         let loop =
@@ -357,9 +357,7 @@ class (Show a) => HVIO a where
 instance HVIO Handle where
     vClose = hClose
     vIsEOF = hIsEOF
-#ifdef __GLASGOW_HASKELL__
     vShow = hShow
-#endif
     vMkIOError h et desc mfp =
         mkIOError et desc (Just h) mfp
     vGetChar = hGetChar
@@ -434,7 +432,7 @@ instance HVIO StreamReader where
                   d <- vioc_get (srv h)
                   return $ case d of
                                   [] -> True
-                                  _ -> False
+                                  _  -> False
     vIsOpen = vioc_isopen . srv
     vGetChar h = do vTestEOF h
                     c <- vioc_get (srv h)
@@ -542,7 +540,7 @@ instance HVIO MemoryBuffer where
            let newpos = case seekmode of
                              AbsoluteSeek -> seekpos
                              RelativeSeek -> pos + seekpos
-                             SeekFromEnd -> (length buf) + seekpos
+                             SeekFromEnd  -> (length buf) + seekpos
            let buf2 = buf ++ if newpos > (length buf)
                                 then replicate (newpos - (length buf)) '\0'
                                 else []
