@@ -8,11 +8,11 @@ For license and copyright information, see the file LICENSE
 -}
 
 module Eithertest(tests) where
-import Test.HUnit
-import Data.Either.Utils
-import Test.HUnit.Tools
-import Control.Exception
-import Control.Exception.ErrorCall.EqInstance
+import           Control.Exception
+import           Control.Exception.ErrorCall.EqInstance
+import           Data.Either.Utils
+import           Test.HUnit
+import           TestUtils
 
 test_maybeToEither =
     let f msg inp exp = TestLabel msg $ TestCase $ assertEqual "" exp inp in
@@ -22,7 +22,7 @@ test_maybeToEither =
          f "Nothing diff types" (maybeToEither "error" (Nothing::Maybe Int))
            (Left "error"),
          f "Just" (maybeToEither "error" (Just "good")) (Right "good"),
-         f "Diff types" (maybeToEither "error" (Just (5::Int))) 
+         f "Diff types" (maybeToEither "error" (Just (5::Int)))
            (Right (5::Int))
         ]
 
@@ -30,9 +30,8 @@ test_forceEither =
     let f msg inp exp = TestLabel msg $ TestCase $ assertEqual "" exp inp in
     [
      f "Right" (forceEither ((Right "foo")::Either Int String)) "foo",
-     TestLabel "Left" $ TestCase $ assertRaises ""
-       (ErrorCallWithLocation "\"wrong\"" "CallStack (from HasCallStack):\n  error, called at src/Data/Either/Utils.hs:51:24 in main:Data.Either.Utils")
-           ("" @=? forceEither (Left "wrong"))
+
+     TestLabel "Left" $ TestCase $ assertRaises ((== "\"wrong\"") . errorCallMsg) ("" @=? forceEither (Left "wrong"))
     ]
 
 tests = TestList [TestLabel "test_maybeToEither" (TestList test_maybeToEither),
