@@ -10,7 +10,7 @@ For license and copyright information, see the file LICENSE
 module IOtest() where
 import Test.HUnit
 import System.IO
-import Test.HUnit.Tools
+import TestUtils
 
 
 
